pub struct Subscription { /* private fields */ }Expand description
An active event subscription returned by Scene::on_* methods.
The subscription is automatically cancelled when the Subscription is
dropped. Keep it alive for as long as you need the callback to fire.
ⓘ
let _update_sub = scene.on_update(|dt| println!("frame dt={dt}"));
// subscription cancelled when _update_sub goes out of scopeTrait Implementations